Class: SocialFramework::RouteHelper::RouteStrategy

Inherits:
Object
  • Object
show all
Defined in:
app/helpers/social_framework/route_helper.rb

Overview

Define a Abstract Class to compare routes

Direct Known Subclasses

RouteStrategyDefault

Instance Method Summary collapse

Instance Method Details

#compare_routes(principal_route, secondary_route, principal_deviation, secondary_deviation) ⇒ Object

Compare the routes to verify if are compatible

Params:
principal_route

Route who gives a lift

secondary_route

Route who hitchhike

principal_deviation

Hash with maximum deviation and mode of travel to principal route

secondary_deviation

Hash with maximum deviation and mode of travel to secondary route

Returns NotImplementedError



15
16
17
# File 'app/helpers/social_framework/route_helper.rb', line 15

def compare_routes(principal_route, secondary_route, principal_deviation, secondary_deviation)
  raise 'Must implement method in subclass'
end