Class: SocialFramework::RouteHelper::RouteStrategy
- Inherits:
-
Object
- Object
- SocialFramework::RouteHelper::RouteStrategy
- Defined in:
- app/helpers/social_framework/route_helper.rb
Overview
Define a Abstract Class to compare routes
Direct Known Subclasses
Instance Method Summary collapse
-
#compare_routes(principal_route, secondary_route, principal_deviation, secondary_deviation) ⇒ Object
- Compare the routes to verify if are compatible ====== Params:
principal_route Routewho gives a liftsecondary_routeRoutewho hitchhikeprincipal_deviationHashwith maximum deviation and mode of travel to principal routesecondary_deviation-
Hashwith maximum deviation and mode of travel to secondary route Returns NotImplementedError.
- Compare the routes to verify if are compatible ====== Params:
Instance Method Details
#compare_routes(principal_route, secondary_route, principal_deviation, secondary_deviation) ⇒ Object
Compare the routes to verify if are compatible
Params:
principal_route-
Routewho gives a lift secondary_route-
Routewho hitchhike principal_deviation-
Hashwith maximum deviation and mode of travel to principal route secondary_deviation-
Hashwith maximum deviation and mode of travel to secondary route
Returns NotImplementedError
15 16 17 |
# File 'app/helpers/social_framework/route_helper.rb', line 15 def compare_routes(principal_route, secondary_route, principal_deviation, secondary_deviation) raise 'Must implement method in subclass' end |